@@ -397,6 +397,10 @@ class Document:
         """Sets the field value not only in memory, but also pushes the change
         to the server."""
         self._get_data()
+
+        if field not in self.keys():
+            raise KeyError(field)
+
         self.torque.site.api(
             "torque",
             format="json",
